.. image:: https://travis-ci.org/latestrevision/django-mailbox.png?branch=master
   :target: https://travis-ci.org/latestrevision/django-mailbox

How many times have you had to consume some sort of POP3, IMAP, or local mailbox for incoming content, 
or had to otherwise construct an application driven by e-mail?
One too many times, I'm sure.

This small Django application will allow you to specify mailboxes that you would like consumed for incoming content; 
the e-mail will be stored, and you can process it at will (or, if you're in a hurry, by subscribing to a signal).

- Documentation for django-mailbox is available on
  `ReadTheDocs <http://django-mailbox.readthedocs.org/>`_.
- Please post issues on
  `BitBucket <http://bitbucket.org/latestrevision/django-mailbox/issues?status=new&status=open>`_.
- Test status available on
  `Travis-CI <https://travis-ci.org/latestrevision/django-mailbox>`_.

